function errors = ZLB_eqm_conditions_stochastic(X,Zss,t_start,a_path,r_path,psi,epsilon,theta,rhoR,phic,phipi,g)
% EXPLANATION
% This code computes the errors for the eqm conditions given X.
% See the equation (1)-(7) in PDF.
% INPUT
% X : eqm objects. If X is a solution, then errors=0.
% Zss : the steady state values.
% tp : when the economy gets away from ZLB
% t_start : date that the simulation starts
% a_path : the path of the technology shock
% r_path : the path of the forecasted interest rate
% others are the parameters. See main_ZLB.m
% OUTPUT 
% errors : size(errors) = (# of eqm conditions) * (time length T )
% Before time T, the economy goes back to SS.


Css=Zss(1);
Rss=Zss(end);
G=g*Zss(3);
M=length(Zss); % number of the endogenous variables.
n=length(X); % Number of the total varialbes.

T=n/M; % time length

% Small check
if floor(T) ~= ceil(T)
    error('fatal wrong length')
end

% reshape Z = (zt_start,ztstart+1,...,zT)
Z=reshape(X,M,T); % Candidate eqm.

% prepare a box
errors=nan(size(Z));


% the economy starts with ZLB

a = a_path(t_start);
err=ZLB_eqm_one_period_stochastic(Zss,Z(:,1),Z(:,2),a,r_path(1),psi,epsilon,theta,rhoR,phic,phipi,G,Rss,Css);
errors(:,1)=err;

for ii = 2 : T-1
	rr = r_path(ii);
	a  = a_path(t_start + ii);
    err=ZLB_eqm_one_period_stochastic(Z(:,ii-1),Z(:,ii),Z(:,ii+1),a,rr,psi,epsilon,theta,rhoR,phic,phipi,G,Rss,Css);
    errors(:,ii) = err;
end



% At the last period.
errors(:,end)=ZLB_eqm_one_period_stochastic(Z(:,T-1),Z(:,T),Zss,a_path(end),r_path(T),psi,epsilon,theta,rhoR,phic,phipi,G,Rss,Css);
% make it colum
errors = errors(:);

